@@ -46,7 +46,7 @@ class CognitoLogin(ff.DomainService, ff.LoggerAware):
                     'access_token': resp['AuthenticationResult']['AccessToken'],
                     'expires_in': resp['AuthenticationResult']['ExpiresIn'],
                     'token_type': resp['AuthenticationResult']['TokenType'],
-                    'decoded_id_token': self._decode_token(resp['AuthenticationResult']['IdToken'])
+                    # 'decoded_id_token': self._decode_token(resp['AuthenticationResult']['IdToken'])
                 }
             }
         else:
